package no.uio.inf5750.example.junit.calculator;

import no.uio.inf5750.example.junit.calculator.impl.DefaultCalculator;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Ignore;
import org.junit.Test;

import static junit.framework.Assert.assertTrue;
import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.fail;

public class CalculatorAnnotatedTest
{
    private Calculator calculator;

    @BeforeClass
    public static void invokedAtClassInstantiation()
    {
        // Do some useful one-time setup work
    }
    
    @Before
    public void beforeEachTest()
    {
        calculator = new DefaultCalculator();
    }
    
    @Test
    public void add()
    {
        int sum = calculator.add( 5, 3 );
        
        assertEquals( 8, sum );
        
        sum = calculator.add( 12, 4 );
        
        assertEquals( 16, sum );        
    }
    
    @Test
    public void multiply()
    {
        int product = calculator.multiply( 4, 3 );
        
        assertTrue( product == 12 );
        
        product = calculator.multiply( 11, 12 );
        
        assertTrue( product == 132 );
    }
    
    @Test( expected = UnsupportedOperationException.class )
    public void divideByZero()
    {
        calculator.divide( 4, 0 );
    }

    @Test
    @Ignore
    public void ignoredTest()
    {
        fail( "This test should be ignored" );
    }
    
    @After
    public void afterEachTest()
    {
        // Do some useful tear-down work
    }

    @AfterClass
    public static void invokedAtClassDestruction()
    {
        // Do some useful tear-down work
    }
}
