package no.uio.inf5750.example.junit.event;

import java.util.Calendar;
import java.util.Date;

import no.uio.inf5750.example.junit.event.dao.EventDAO;
import no.uio.inf5750.example.junit.event.dao.memory.MemoryEventDAO;
import no.uio.inf5750.example.junit.event.model.Event;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import static junit.framework.Assert.*;

public class EventDAOAnnotatedTest
{
    private EventDAO eventDAO;
    
    private Date date;
    
    private Event event;
    
    @Before
    public void invokedBeforeTests() // Sets up the test fixture
    {
        eventDAO = new MemoryEventDAO(); // Instantiating a new EventDAO for each test
        
        Calendar calendar = Calendar.getInstance();
        
        calendar.set( 2007, Calendar.NOVEMBER, 10 );
        
        date = calendar.getTime();
        
        event = new Event( "U2 concert", date ); // Creating a convenient Event instance
    }
    
    @Test
    public void addEvent()
    {
        int id = eventDAO.saveEvent( event );
        
        event = eventDAO.getEvent( id );
        
        assertEquals( id, event.getId() ); // Verify equality between the added and the retrieved object
        assertEquals( "U2 concert", event.getTitle() );        
        assertEquals( date, event.getDate() );
    }

    @Test
    public void getEvent()
    {
        int id = eventDAO.saveEvent( event );

        event = eventDAO.getEvent( id );
        
        assertNotNull( event );
        
        assertEquals( id, event.getId() );        
        assertEquals( "U2 concert", event.getTitle() );        
        assertEquals( date, event.getDate() );
        
        event = eventDAO.getEvent( -1 );
        
        assertNull( event ); // Verify that null is returned when object does not exist               
    }

    @Test
    public void deleteEvent()
    {
        int id = eventDAO.saveEvent( event );
        
        event = eventDAO.getEvent( id );
        
        assertNotNull( event ); // Verify that event exists
        
        eventDAO.deleteEvent( id );
        
        event = eventDAO.getEvent( id );
        
        assertNull( event ); // Verify that event has been deleted
    }
    
    @After
    public void invokedAfterTests()
    {
        // Do some useful tear-down work
    }
}
