package no.uio.inf5750.example.junit.event;

import java.util.Calendar;
import java.util.Date;

import no.uio.inf5750.example.junit.event.dao.EventDAO;
import no.uio.inf5750.example.junit.event.dao.memory.MemoryEventDAO;
import no.uio.inf5750.example.junit.event.model.Event;

import junit.framework.TestCase;

public class EventDAOTest
    extends TestCase
{
    private EventDAO eventDAO;
    
    private Date date;
    
    private Event event;
    
    @Override
    public void setUp() // Sets up the test fixture
    {
        eventDAO = new MemoryEventDAO(); // Instantiating a new EventDAO for each test
        
        Calendar calendar = Calendar.getInstance();
        
        calendar.set( 2007, Calendar.NOVEMBER, 10 );
        
        date = calendar.getTime();
        
        event = new Event( "U2 concert", date ); // Creating a convenient Event instance
    }
    
    public void testAddEvent()
    {
        int id = eventDAO.saveEvent( event );
        
        event = eventDAO.getEvent( id );
        
        assertEquals( id, event.getId()  ); // Verify equality between the added and the retrieved object
        assertEquals( "U2 concert", event.getTitle() );        
        assertEquals( date, event.getDate() );
    }

    public void testGetEvent()
    {
        int id = eventDAO.saveEvent( event );

        event = eventDAO.getEvent( id );
        
        assertNotNull( event );
        
        assertEquals( id, event.getId() );        
        assertEquals( "U2 concert", event.getTitle() );        
        assertEquals( date, event.getDate() );
        
        event = eventDAO.getEvent( -1 );
        
        assertNull( event ); // Verify that null is returned when object does not exist               
    }

    public void testDeleteEvent()
    {
        int id = eventDAO.saveEvent( event );
        
        event = eventDAO.getEvent( id );
        
        assertNotNull( event ); // Verify that event exists
        
        eventDAO.deleteEvent( id );
        
        event = eventDAO.getEvent( id );
        
        assertNull( event ); // Verify that event has been deleted
    }
}
